@@ -54,12 +54,13 @@ void load_control(void){
   double mxLoad = atof(db_get("max-loadavg", 0));
   if( mxLoad<=0.0 || mxLoad>=load_average() ) return;
 
+  style_set_current_feature("test");
   style_header("Server Overload");
   @ <h2>The server load is currently too high.
   @ Please try again later.</h2>
   @ <p>Current load average: %f(load_average()).<br />
   @ Load average limit: %f(mxLoad)</p>
-  style_footer();
+  style_finish_page();
   cgi_set_status(503,"Server Overload");
   cgi_reply();
   exit(0);
